@@ -1,5 +1,6 @@
 package Catalyst::Controller::DBIC::API::Request;
-our $VERSION = '2.001003';
+$Catalyst::Controller::DBIC::API::Request::VERSION = '2.002001';
+$Catalyst::Controller::DBIC::API::Request::VERSION = '2.002001';
 
 #ABSTRACT: Provides a role to be applied to the Request object
 use Moose::Role;
@@ -28,7 +29,7 @@ has '_controller' =>
         my ($self, $new) = @_;
 
         $self->_set_class($new->class) if defined($new->class);
-        $self->_set_application($new->_application); 
+        $self->_set_application($new->_application);
         $self->_set_prefetch_allows($new->prefetch_allows);
         $self->_set_search_exposes($new->search_exposes);
         $self->_set_select_exposes($new->select_exposes);
@@ -51,7 +52,7 @@ Catalyst::Controller::DBIC::API::Request - Provides a role to be applied to the
 
 =head1 VERSION
 
-version 2.001003
+version 2.002001
 
 =head1 DESCRIPTION
 
@@ -68,6 +69,7 @@ This attribute helps bridge between the request guts and the application guts; a
   Nicholas Perez <nperez@cpan.org>
   Luke Saunders <luke.saunders@gmail.com>
   Alexander Hartmaier <abraxxa@cpan.org>
+  Florian Ragwitz <rafl@debian.org>
 
 =head1 COPYRIGHT AND LICENSE
 
